@@ -1,7 +1,7 @@
 /* packet-kdp.c
  * Routines for KDP (Kontiki Delivery Protocol) packet disassembly
  *
- * $Id: packet-kdp.c 27037 2008-12-17 17:23:37Z wmeier $
+ * $Id: packet-kdp.c 28139 2009-04-23 19:06:26Z etxrab $
  *
  * Copyright (c) 2008 by Kontiki Inc.
  *                    Wade Hennessey <wade@kontiki.com>
@@ -78,9 +78,9 @@ static void dissect_kdp(tvbuff_t *tvb,
   guint8 header_len = 0;
   guint8 packet_flags = 0;
   guint8 packet_errors = 0;
-  guint32 sequence_number = -1;
-  guint32 ack_number = -1; 
-  guint32 src_flowid = -1; 
+  guint32 sequence_number = G_MAXUINT32;
+  guint32 ack_number = G_MAXUINT32; 
+  guint32 src_flowid = G_MAXUINT32; 
   int offset;
 
   if (check_col(pinfo->cinfo, COL_PROTOCOL)) {
@@ -102,6 +102,7 @@ static void dissect_kdp(tvbuff_t *tvb,
     version = tvb_get_guint8(tvb, 0);
     if (version != 2) {
       /* Version other than 2 is really SDDP in UDP */
+      proto_tree_add_item(kdp_tree, hf_kdp_version, tvb, 0, 1, FALSE);
       proto_tree_add_item(kdp_tree, hf_kdp_xml_body, tvb, 0, -1, FALSE);
     } else {
       header_len = tvb_get_guint8(tvb, 1) * 4;
@@ -207,25 +208,19 @@ static void dissect_kdp(tvbuff_t *tvb,
       char src_flowid_string[BUFFER_SIZE];
 
       if (packet_flags & KDP_ACK_FLAG) {
-	int numchars = g_snprintf(ack_string, sizeof(ack_string),
-				  "ACK=%x ", ack_number);
-	ack_string[numchars] = 0;
+	g_snprintf(ack_string, sizeof(ack_string), "ACK=%x ", ack_number);
       } else {
-	ack_string[0] = 0;
+	ack_string[0] = '\0';
       }
       if (header_len > 4) {
-	int numchars = g_snprintf(seq_num_string, sizeof(seq_num_string),
-				  "SEQ=%x ", sequence_number);
-	seq_num_string[numchars] = 0;
+	g_snprintf(seq_num_string, sizeof(seq_num_string), "SEQ=%x ", sequence_number);
       } else {
-	seq_num_string[0] = 0;
+	seq_num_string[0] = '\0';
       }
       if (packet_flags & (KDP_SYN_FLAG | KDP_BCST_FLAG)) {
-	int numchars = g_snprintf(src_flowid_string, sizeof(ack_string),
-				  "SRC_FLOWID=%x ", src_flowid);
-	src_flowid_string[numchars] = 0;
+	g_snprintf(src_flowid_string, sizeof(src_flowid_string), "SRC_FLOWID=%x ", src_flowid);
       } else {
-	src_flowid_string[0] = 0;
+	src_flowid_string[0] = '\0';
       }
       col_add_fstr(pinfo->cinfo, COL_INFO, "%s%s%s%s%s%s%s%serrors=%d",
 		   ((packet_flags & KDP_DROP_FLAG) ? "DROP " : ""),
