@@ -5,7 +5,7 @@
  *
  * Copyright 2001, Heinz Prantner <heinz.prantner[AT]radisys.com>
  *
- * $Id: packet-m2tp.c 18196 2006-05-21 04:49:01Z sahlberg $
+ * $Id: packet-m2tp.c 26196 2008-09-15 15:38:34Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -243,7 +243,6 @@ static gint ett_m2tp = -1;
 static gint ett_m2tp_parameter = -1;
 
 static dissector_handle_t mtp2_handle;
-static int mtp2_proto_id;
 
 static guint
 nr_of_padding_bytes (guint length)
@@ -670,7 +669,6 @@ proto_reg_handoff_m2tp(void)
 {
   dissector_handle_t m2tp_handle;
   mtp2_handle   = find_dissector("mtp2");
-  mtp2_proto_id = proto_get_id_by_filter_name("mtp2");
   m2tp_handle   = create_dissector_handle(dissect_m2tp, proto_m2tp);
   dissector_add("sctp.ppi",  M2TP_PAYLOAD_PROTOCOL_ID, m2tp_handle);
   dissector_add("sctp.port", SCTP_PORT_M2TP, m2tp_handle);
